You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by mc...@apache.org on 2008/05/22 15:34:09 UTC

svn commit: r659108 [18/19] - in /harmony/enhanced/drlvm/trunk/vm: em/src/ gc_gen/src/common/ gc_gen/src/mark_compact/ gc_gen/src/mark_sweep/ gc_gen/src/semi_space/ gc_gen/src/trace_forward/ include/open/ interpreter/src/ jitrino/src/codegenerator/ jit...

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/C_Interface.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/C_Interface.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class.cpp Thu May 22 06:33:38 2008
@@ -723,8 +723,8 @@
     _class->unlock();
 }
 
-void Method::add_inline_info_entry(Method* method, uint32 codeSize, void* codeAddr,
-        uint32 mapLength, AddrLocation* addrLocationMap) {
+void Method::add_inline_info_entry(Method* method, U_32 codeSize, void* codeAddr,
+        U_32 mapLength, AddrLocation* addrLocationMap) {
     if (NULL == _inline_info) 
         _inline_info = new InlineInfo();
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class_File_Loader.cpp Thu May 22 06:33:38 2008
@@ -169,7 +169,7 @@
 }
 
 static String* parse_signature_attr(ByteReader &cfs,
-                             uint32 attr_len,
+                             U_32 attr_len,
                              Class* clss)
 {
     //See specification 4.8.8 about attribute length
@@ -194,7 +194,7 @@
 Attributes parse_attribute(Class *clss,
                            ByteReader &cfs,
 			   AttributeID* attrs,
-                           uint32 *attr_len)
+                           U_32 *attr_len)
 {
     static bool UNUSED init = preload_attrs(VM_Global_State::loader_env->string_pool);
     //See specification 4.8 about Attributes
@@ -231,11 +231,11 @@
 } //parse_attribute
 
 // forward declaration
-static uint32
+static U_32
 parse_annotation_value(AnnotationValue& value, ByteReader& cfs, Class* clss);
 
 // returns number of read bytes, 0 if error occurred
-static uint32
+static U_32
 parse_annotation(Annotation** value, ByteReader& cfs, Class* clss)
 {
     unsigned initial_offset = cfs.get_offset();
@@ -285,7 +285,7 @@
 }
 
 // returns number of read bytes, 0 if error occurred
-static uint32
+static U_32
 parse_annotation_value(AnnotationValue& value, ByteReader& cfs, Class* clss)
 {
     unsigned initial_offset = cfs.get_offset();
@@ -434,7 +434,7 @@
 }
 
 // returns number of read bytes, 0 if error occurred
-static uint32
+static U_32
 parse_annotation_table(AnnotationTable ** table, ByteReader& cfs, Class* clss)
 {
     unsigned initial_offset = cfs.get_offset();
@@ -465,7 +465,7 @@
     return cfs.get_offset() - initial_offset;
 }
 
-static uint32
+static U_32
 parse_parameter_annotations(AnnotationTable *** table,
                                         uint8 num_annotations,
                                         ByteReader& cfs, Class* clss)
@@ -533,21 +533,21 @@
 static bool
 is_identifier(const char *name, unsigned len)
 {
-    uint32 u_ch;
+    U_32 u_ch;
     for(unsigned i = 0; i < len;) {
         unsigned ch_len = 0;
         if(name[i] & 0x80) {
             assert(name[i] & 0x40);
             if(name[i] & 0x20) {
-                uint32 x = name[i];
-                uint32 y = name[i + 1];
-                uint32 z = name[i + 2];
-                u_ch = (uint32)(((0x0f & x) << 12) + ((0x3f & y) << 6) + ((0x3f & z)));
+                U_32 x = name[i];
+                U_32 y = name[i + 1];
+                U_32 z = name[i + 2];
+                u_ch = (U_32)(((0x0f & x) << 12) + ((0x3f & y) << 6) + ((0x3f & z)));
                 ch_len = 3;
             } else {
-                uint32 x = name[i];
-                uint32 y = name[i + 1];
-                u_ch = (uint32)(((0x1f & x) << 6) + (0x3f & y));
+                U_32 x = name[i];
+                U_32 y = name[i + 1];
+                u_ch = (U_32)(((0x1f & x) << 6) + (0x3f & y));
                 ch_len = 2;
             }
         } else {
@@ -796,7 +796,7 @@
     unsigned numConstantValue = 0;
     unsigned numRuntimeVisibleAnnotations = 0;
     unsigned numRuntimeInvisibleAnnotations = 0;
-    uint32 attr_len = 0;
+    U_32 attr_len = 0;
 
     ConstantPool& cp = clss->get_constant_pool();
 
@@ -968,7 +968,7 @@
                     return false;
                 }
 
-                uint32 read_len = parse_annotation_table(&_annotations, cfs, clss);
+                U_32 read_len = parse_annotation_table(&_annotations, cfs, clss);
                 if(read_len == 0)
                     return false;
                 if (attr_len != read_len) {
@@ -991,7 +991,7 @@
                     return false;
                 }
                 if(env.retain_invisible_annotations) {
-                    uint32 read_len =
+                    U_32 read_len =
                         parse_annotation_table(&_invisible_annotations, cfs, clss);
                     if(read_len == 0)
                         return false;
@@ -1459,7 +1459,7 @@
 
     static bool TI_enabled = VM_Global_State::loader_env->TI->isEnabled();
 
-    uint32 attr_len = 0;
+    U_32 attr_len = 0;
     LocalVarOffset* offset_lvt_array = NULL;
     LocalVarOffset* lvt_iter = NULL;
     LocalVarOffset* offset_lvtt_array = NULL;
@@ -1890,7 +1890,7 @@
     unsigned numRuntimeVisibleAnnotations = 0;
     unsigned numRuntimeInvisibleAnnotations = 0;
     unsigned numRuntimeInvisibleParameterAnnotations = 0;
-    uint32 attr_len = 0;
+    U_32 attr_len = 0;
     ConstantPool& cp = clss->get_constant_pool();
 
     for (unsigned j=0; j<attr_count; j++) {
@@ -1938,9 +1938,9 @@
                             "truncated class file: failed to parse number of InvisibleParameterAnnotations");
                         return false;
                     }
-                    uint32 read_len = 1;
+                    U_32 read_len = 1;
                     if (_num_invisible_param_annotations) {
-                        uint32 len =
+                        U_32 len =
                             parse_parameter_annotations(&_invisible_param_annotations,
                                         _num_invisible_param_annotations, cfs, _class);  
                         if(len == 0)
@@ -1979,9 +1979,9 @@
                         "cannot parse number of ParameterAnnotations");
                     return false;
                 }
-                uint32 read_len = 1;
+                U_32 read_len = 1;
                 if (_num_param_annotations) {
-                    uint32 len = parse_parameter_annotations(&_param_annotations,
+                    U_32 len = parse_parameter_annotations(&_param_annotations,
                                     _num_param_annotations, cfs, _class);
                     if(len == 0)
                         return false;
@@ -2007,7 +2007,7 @@
                 _default_value = (AnnotationValue *)_class->get_class_loader()->Alloc(
                     sizeof(AnnotationValue));
                 //FIXME: verav should throw OOM
-                uint32 read_len = parse_annotation_value(*_default_value, cfs, clss);
+                U_32 read_len = parse_annotation_value(*_default_value, cfs, clss);
                 if (read_len == 0) {
                     return false;
                 } else if (read_len != attr_len) {
@@ -2066,7 +2066,7 @@
                     return false;
                 }
 
-                uint32 read_len = parse_annotation_table(&_annotations, cfs, clss);
+                U_32 read_len = parse_annotation_table(&_annotations, cfs, clss);
                 if(read_len == 0)
                     return false;
                 if (attr_len != read_len) {
@@ -2091,7 +2091,7 @@
                 //RuntimeInvisibleAnnotations attribute is parsed only if
                 //command line option -Xinvisible is set. See specification 4.8.15.
                 if(env.retain_invisible_annotations) {
-                    uint32 read_len =
+                    U_32 read_len =
                         parse_annotation_table(&_invisible_annotations, cfs, clss);
                     if(read_len == 0)
                         return false;
@@ -2770,7 +2770,7 @@
     /*
      *  get and check magic number (Oxcafebabe)
      */
-    uint32 magic;
+    U_32 magic;
     if (!cfs.parse_u4_be(&magic)) {
         REPORT_FAILED_CLASS_FORMAT(this, "class is not a valid Java class file");
         return false;
@@ -2995,7 +2995,7 @@
     unsigned numEnclosingMethods = 0;
     unsigned numRuntimeVisibleAnnotations = 0;
     unsigned numRuntimeInvisibleAnnotations = 0;
-    uint32 attr_len = 0;
+    U_32 attr_len = 0;
 
     for (unsigned i=0; i<n_attrs; i++) {
         Attributes cur_attr = parse_attribute(this, cfs, class_attrs, &attr_len);
@@ -3253,7 +3253,7 @@
                         "more than one RuntimeVisibleAnnotations attribute");
                     return false;
                 }
-                uint32 read_len = parse_annotation_table(&m_annotations, cfs, this);
+                U_32 read_len = parse_annotation_table(&m_annotations, cfs, this);
                 if(attr_len == 0)
                     return false;
                 if (attr_len != read_len) {
@@ -3276,7 +3276,7 @@
                             "more than one RuntimeInvisibleAnnotations attribute");
                         return false;
                     }
-                    uint32 read_len = parse_annotation_table(&m_invisible_annotations, cfs, this);
+                    U_32 read_len = parse_annotation_table(&m_invisible_annotations, cfs, this);
                     if(read_len == 0)
                         return false;
                     if (attr_len != read_len) {
@@ -3386,7 +3386,7 @@
 {
     ByteReader cfs(buffer, offset, length);
 
-    uint32 magic;
+    U_32 magic;
     // check magic
     if(!cfs.parse_u4_be(&magic) || magic != CLASSFILE_MAGIC)
         return NULL;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/String_Pool.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/String_Pool.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/String_Pool.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/String_Pool.cpp Thu May 22 06:33:38 2008
@@ -359,8 +359,8 @@
         COMPRESSED_REFERENCE compressed_lang_string =
             compress_reference(string->object);
         assert(is_compressed_reference(compressed_lang_string));
-        uint32 result = apr_atomic_cas32(
-            /*destination*/ (volatile uint32 *)&str->intern.compressed_ref, 
+        U_32 result = apr_atomic_cas32(
+            /*destination*/ (volatile U_32 *)&str->intern.compressed_ref, 
             /*exchange*/    compressed_lang_string,
             /*comparand*/   0);
         if (result == 0) {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/inline_info.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/inline_info.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/inline_info.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/inline_info.cpp Thu May 22 06:33:38 2008
@@ -25,8 +25,8 @@
 InlineInfo::InlineInfo(): _entries(0)
 {}
 
-void InlineInfo::add(Method* method, uint32 codeSize, void* codeAddr, 
-                     uint32 mapLength, AddrLocation* addrLocationMap)
+void InlineInfo::add(Method* method, U_32 codeSize, void* codeAddr, 
+                     U_32 mapLength, AddrLocation* addrLocationMap)
 {
     Entry entry = {method, codeSize, codeAddr, mapLength, addrLocationMap};
  

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/exception/exceptions_jit.cpp Thu May 22 06:33:38 2008
@@ -98,7 +98,7 @@
 #ifdef POINTER64
 typedef uint64 NumericNativeCodePtr;
 #else
-typedef uint32 NumericNativeCodePtr;
+typedef U_32 NumericNativeCodePtr;
 #endif
 
 bool Target_Exception_Handler::is_in_range(NativeCodePtr ip, bool is_ip_past)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/dll_gc.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/dll_gc.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/dll_gc.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/dll_gc.cpp Thu May 22 06:33:38 2008
@@ -32,7 +32,7 @@
 static void default_gc_write_barrier(Managed_Object_Handle);
 static void default_gc_pin_object(Managed_Object_Handle*);
 static void default_gc_unpin_object(Managed_Object_Handle*);
-static int32 default_gc_get_hashcode(Managed_Object_Handle);
+static I_32 default_gc_get_hashcode(Managed_Object_Handle);
 static Managed_Object_Handle default_gc_get_next_live_object(void*);
 static void default_gc_iterate_heap();
 static void default_gc_finalize_on_exit();
@@ -46,20 +46,20 @@
                                            Managed_Object_Handle *p_slot,
                                            Managed_Object_Handle value);
 static void default_gc_heap_slot_write_ref_compressed(Managed_Object_Handle p_base_of_object_with_slot,
-                                                      uint32 *p_slot,
+                                                      U_32 *p_slot,
                                                       Managed_Object_Handle value);
 static void default_gc_heap_write_global_slot(Managed_Object_Handle *p_slot,
                                               Managed_Object_Handle value);
-static void default_gc_heap_write_global_slot_compressed(uint32 *p_slot,
+static void default_gc_heap_write_global_slot_compressed(U_32 *p_slot,
                                                          Managed_Object_Handle value);
 static void default_gc_heap_wrote_object(Managed_Object_Handle p_base_of_object_just_written);
-static void default_gc_add_compressed_root_set_entry(uint32 *ref);
+static void default_gc_add_compressed_root_set_entry(U_32 *ref);
 static void default_gc_add_root_set_entry_managed_pointer(void **slot,
                                                           Boolean is_pinned);
 static void *default_gc_heap_base_address();
 static void *default_gc_heap_ceiling_address();
 static void default_gc_test_safepoint();
-/* $$$ GMJ static int32 default_gc_get_hashcode(Managed_Object_Handle); */
+/* $$$ GMJ static I_32 default_gc_get_hashcode(Managed_Object_Handle); */
 
 static Boolean default_gc_supports_frontier_allocation(unsigned *offset_of_current, unsigned *offset_of_limit);
 static void default_gc_add_weak_root_set_entry(
@@ -70,7 +70,7 @@
 Boolean (*gc_supports_compressed_references)() = 0;
 void (*gc_add_root_set_entry)(Managed_Object_Handle *ref, Boolean is_pinned) = 0;
 void (*gc_add_weak_root_set_entry)(Managed_Object_Handle *ref, Boolean is_pinned,Boolean is_short_weak) = 0;
-void (*gc_add_compressed_root_set_entry)(uint32 *ref, Boolean is_pinned) = 0;
+void (*gc_add_compressed_root_set_entry)(U_32 *ref, Boolean is_pinned) = 0;
 void (*gc_add_root_set_entry_interior_pointer)(void **slot, int offset, Boolean is_pinned) = 0;
 void (*gc_add_root_set_entry_managed_pointer)(void **slot, Boolean is_pinned) = 0;
 void (*gc_class_prepared)(Class_Handle ch, VTable_Handle vth) = 0;
@@ -82,11 +82,11 @@
                                Managed_Object_Handle *p_slot,
                                Managed_Object_Handle value) = 0;
 void (*gc_heap_slot_write_ref_compressed)(Managed_Object_Handle p_base_of_object_with_slot,
-                                          uint32 *p_slot,
+                                          U_32 *p_slot,
                                           Managed_Object_Handle value) = 0;
 void (*gc_heap_write_global_slot)(Managed_Object_Handle *p_slot,
                                   Managed_Object_Handle value) = 0;
-void (*gc_heap_write_global_slot_compressed)(uint32 *p_slot,
+void (*gc_heap_write_global_slot_compressed)(U_32 *p_slot,
                                              Managed_Object_Handle value) = 0;
 void (*gc_heap_write_ref)(Managed_Object_Handle p_base_of_object_with_slot,
                                  unsigned offset,
@@ -119,9 +119,9 @@
 
 void (*gc_pin_object)(Managed_Object_Handle* p_object) = 0;
 void (*gc_unpin_object)(Managed_Object_Handle* p_object) = 0;
-int32 (*gc_get_hashcode)(Managed_Object_Handle obj) = 0;
+I_32 (*gc_get_hashcode)(Managed_Object_Handle obj) = 0;
 Managed_Object_Handle (*gc_get_next_live_object)(void *iterator) = 0;
-int32 (*gc_get_hashcode0) (Managed_Object_Handle p_object) = 0;
+I_32 (*gc_get_hashcode0) (Managed_Object_Handle p_object) = 0;
 void (*gc_iterate_heap)() = 0;
 
 void (*gc_finalize_on_exit)() = 0;
@@ -184,7 +184,7 @@
         getFunctionOptional(handle, "gc_add_weak_root_set_entry", dllName,
                 (apr_dso_handle_sym_t) default_gc_add_weak_root_set_entry); 
 
-    gc_add_compressed_root_set_entry = (void (*)(uint32 *ref, Boolean is_pinned)) 
+    gc_add_compressed_root_set_entry = (void (*)(U_32 *ref, Boolean is_pinned)) 
         getFunctionOptional(handle, 
                             "gc_add_compressed_root_set_entry", 
                             dllName,
@@ -208,7 +208,7 @@
                             dllName,
                             (apr_dso_handle_sym_t)default_gc_heap_slot_write_ref);
     gc_heap_slot_write_ref_compressed = (void (*)(Managed_Object_Handle p_base_of_object_with_slot,
-                                                  uint32 *p_slot,
+                                                  U_32 *p_slot,
                                                   Managed_Object_Handle value))
         getFunctionOptional(handle,
                             "gc_heap_slot_write_ref_compressed",
@@ -220,7 +220,7 @@
                             "gc_heap_write_global_slot",
                             dllName,
                             (apr_dso_handle_sym_t)default_gc_heap_write_global_slot);
-    gc_heap_write_global_slot_compressed = (void (*)(uint32 *p_slot,
+    gc_heap_write_global_slot_compressed = (void (*)(U_32 *p_slot,
                                                      Managed_Object_Handle value))        
         getFunctionOptional(handle,
                             "gc_heap_write_global_slot_compressed",
@@ -253,7 +253,7 @@
         getFunctionOptional(handle, "gc_unpin_object", dllName,
             (apr_dso_handle_sym_t)default_gc_unpin_object);
 
-    gc_get_hashcode = (int32 (*)(Managed_Object_Handle))
+    gc_get_hashcode = (I_32 (*)(Managed_Object_Handle))
         getFunctionOptional(handle, "gc_get_hashcode", dllName,
             (apr_dso_handle_sym_t)default_gc_get_hashcode);
 
@@ -277,7 +277,7 @@
         getFunctionOptional(handle, "gc_clear_mutator_block_flag", dllName,
             (apr_dso_handle_sym_t)default_gc_clear_mutator_block_flag);
 
-    gc_get_hashcode0 = (int32 (*)(Managed_Object_Handle))
+    gc_get_hashcode0 = (I_32 (*)(Managed_Object_Handle))
         getFunctionOptional(handle, "gc_get_hashcode", dllName, (apr_dso_handle_sym_t) default_gc_get_hashcode);
 
     gc_vm_initialized = (void (*)()) getFunction(handle, "gc_vm_initialized", dllName);
@@ -377,7 +377,7 @@
 
 
 static void default_gc_heap_slot_write_ref_compressed(Managed_Object_Handle UNREF p_base_of_object_with_slot,
-                                                      uint32 *p_slot,
+                                                      U_32 *p_slot,
                                                       Managed_Object_Handle value)
 {
     // p_slot is the address of a 32 bit slot holding the offset of a referenced object in the heap.
@@ -405,7 +405,7 @@
 
 
 
-static void default_gc_heap_write_global_slot_compressed(uint32 *p_slot,
+static void default_gc_heap_write_global_slot_compressed(U_32 *p_slot,
                                                          Managed_Object_Handle value)
 {
     // p_slot is the address of a 32 bit global variable holding the offset of a referenced object in the heap.
@@ -430,7 +430,7 @@
 
 
 
-static void default_gc_add_compressed_root_set_entry(uint32 * UNREF ref)
+static void default_gc_add_compressed_root_set_entry(U_32 * UNREF ref)
 {
     LDIE(7, "Fatal GC error: compressed references are not supported.");
 } //default_gc_add_compressed_root_set_entry
@@ -456,7 +456,7 @@
     return FALSE;
 }
 
-static int32 default_gc_get_hashcode(Managed_Object_Handle obj) {
+static I_32 default_gc_get_hashcode(Managed_Object_Handle obj) {
     return default_hashcode(obj);
 }
 
@@ -496,7 +496,7 @@
 }
 
 /* $$$ GMJ
-static int32 default_gc_get_hashcode(Managed_Object_Handle obj)
+static I_32 default_gc_get_hashcode(Managed_Object_Handle obj)
 {
     return default_hashcode((ManagedObject*) obj);
 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/root_set_enum_common.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/root_set_enum_common.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/finalizer_thread.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/finalizer_thread.cpp Thu May 22 06:33:38 2008
@@ -34,11 +34,11 @@
 static Fin_Thread_Info *fin_thread_info = NULL;
 unsigned int cpu_num_bits;
 
-static uint32 atomic_inc32(volatile apr_uint32_t *mem)
-{  return (uint32)apr_atomic_inc32(mem); }
+static U_32 atomic_inc32(volatile apr_uint32_t *mem)
+{  return (U_32)apr_atomic_inc32(mem); }
 
-static uint32 atomic_dec32(volatile apr_uint32_t *mem)
-{  return (uint32)apr_atomic_dec32(mem); }
+static U_32 atomic_dec32(volatile apr_uint32_t *mem)
+{  return (U_32)apr_atomic_dec32(mem); }
 
 Boolean get_native_finalizer_thread_flag()
 {  return native_fin_thread_flag; }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/ref_enqueue_thread.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/ref_enqueue_thread.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/ref_enqueue_thread.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/ref_enqueue_thread.cpp Thu May 22 06:33:38 2008
@@ -82,11 +82,11 @@
     activate_ref_enqueue_thread(FALSE);
 }
 
-static uint32 atomic_inc32(volatile apr_uint32_t *mem)
-{  return (uint32)apr_atomic_inc32(mem); }
+static U_32 atomic_inc32(volatile apr_uint32_t *mem)
+{  return (U_32)apr_atomic_inc32(mem); }
 
-static uint32 atomic_dec32(volatile apr_uint32_t *mem)
-{  return (uint32)apr_atomic_dec32(mem); }
+static U_32 atomic_dec32(volatile apr_uint32_t *mem)
+{  return (U_32)apr_atomic_dec32(mem); }
 
 void wait_native_ref_thread_detached(void)
 {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/dll_jit.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/dll_jit.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/dll_jit.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/dll_jit.cpp Thu May 22 06:33:38 2008
@@ -80,13 +80,13 @@
     _recompiled_method_callback = (Boolean (*)(JIT_Handle, Method_Handle, void *)) fn;
 
     GET_OPTIONAL_FUNCTION(fn, handle, "JIT_get_inline_depth");
-    _get_inline_depth = (uint32 (*)(JIT_Handle, InlineInfoPtr, uint32)) fn;
+    _get_inline_depth = (U_32 (*)(JIT_Handle, InlineInfoPtr, U_32)) fn;
 
     GET_OPTIONAL_FUNCTION(fn, handle, "JIT_get_inlined_method");
-    _get_inlined_method = (Method_Handle (*)(JIT_Handle, InlineInfoPtr, uint32, uint32)) fn;
+    _get_inlined_method = (Method_Handle (*)(JIT_Handle, InlineInfoPtr, U_32, U_32)) fn;
 
     GET_OPTIONAL_FUNCTION(fn, handle, "JIT_get_inlined_bc");
-    _get_inlined_bc = (uint16 (*)(JIT_Handle, InlineInfoPtr, uint32, uint32)) fn;
+    _get_inlined_bc = (uint16 (*)(JIT_Handle, InlineInfoPtr, U_32, U_32)) fn;
 
     GET_FUNCTION(fn, handle, "JIT_unwind_stack_frame");
     _unwind_stack_frame = (void (*)(JIT_Handle, Method_Handle, JitFrameContext *)) fn;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/jit_runtime_support.cpp Thu May 22 06:33:38 2008
@@ -474,7 +474,7 @@
     ManagedObject* null_ref = (ManagedObject*)VM_Global_State::loader_env->managed_null;
     if (array == null_ref) {
         return env->java_lang_NullPointerException_Class;
-    } else if (((uint32)idx) >= (uint32)get_vector_length(array)) {
+    } else if (((U_32)idx) >= (U_32)get_vector_length(array)) {
         return env->java_lang_ArrayIndexOutOfBoundsException_Class;
     } else if (elem != null_ref) {
         assert(get_vector_vtable(array));
@@ -2348,7 +2348,7 @@
     ManagedObject *null_ref = (ManagedObject *)VM_Global_State::loader_env->managed_null;
     if (array == null_ref) {
         return env->java_lang_NullPointerException_Class;
-    } else if (((uint32)idx) >= (uint32)get_vector_length(array)) {
+    } else if (((U_32)idx) >= (U_32)get_vector_length(array)) {
         return env->java_lang_ArrayIndexOutOfBoundsException_Class;
     } else if (elem != null_ref) {
         Class *array_class = get_vector_vtable(array)->clss;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/native_overrides.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/native_overrides.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/native_overrides.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jit/native_overrides.cpp Thu May 22 06:33:38 2008
@@ -178,7 +178,7 @@
 
 LilCodeStub* nso_array_copy(LilCodeStub* cs, Method_Handle)
 {
-    ArrayCopyResult (*p_array_copy)(ManagedObject* src, int32 src_off, ManagedObject* dst, int32 dst_off, int32 count);
+    ArrayCopyResult (*p_array_copy)(ManagedObject* src, I_32 src_off, ManagedObject* dst, I_32 dst_off, I_32 count);
     p_array_copy = array_copy;
     cs = lil_parse_onto_end(cs,
         "in2out platform:g4;"

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni_array.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni_array.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni_array.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jni/jni_array.cpp Thu May 22 06:33:38 2008
@@ -41,7 +41,7 @@
     ObjectHandle h = (ObjectHandle)array;
 
     tmn_suspend_disable();   //-----------------v
-    uint32 length = get_vector_length((Vector_Handle)h->object);
+    U_32 length = get_vector_length((Vector_Handle)h->object);
     tmn_suspend_enable();    //---------------------------------^
 
     return length;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp Thu May 22 06:33:38 2008
@@ -552,8 +552,8 @@
 #ifdef _IA32_
     return push(code_addr, Imm_Opnd(size_32, value));
 #elif defined _EM64T_
-    int32 high = (int32)((uint32)(value >> 32));
-    int32 low = (int32)((uint32)value);
+    I_32 high = (I_32)((U_32)(value >> 32));
+    I_32 low = (I_32)((U_32)value);
     code_addr = alu(code_addr, sub_opc, rsp_opnd, Imm_Opnd(size_8, 8));
     code_addr = mov(code_addr, M_Base_Opnd(rsp_reg, 4), Imm_Opnd(size_32, high), size_32);
     return mov(code_addr, M_Base_Opnd(rsp_reg, 0), Imm_Opnd(size_32, low), size_32);
@@ -1408,13 +1408,13 @@
     jlocation *locations = (jlocation *)STD_MALLOC(sizeof(jlocation) *
         method->get_pending_breakpoints());
     assert(locations);
-    uint32 location_count = 0;
+    U_32 location_count = 0;
 
     do
     {
         // It is necessary to set breakpoints only once for each
         // location, so we need to filter out duplicate breakpoints
-        for (uint32 iii = 0; iii < location_count; iii++)
+        for (U_32 iii = 0; iii < location_count; iii++)
             if (bp->location == locations[iii])
                 continue;
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp Thu May 22 06:33:38 2008
@@ -562,8 +562,8 @@
     oh_discard_local_handle(hThread);
 }
 
-void jvmti_send_region_compiled_method_load_event(Method *method, uint32 codeSize, 
-                                  const void* codeAddr, uint32 mapLength, 
+void jvmti_send_region_compiled_method_load_event(Method *method, U_32 codeSize, 
+                                  const void* codeAddr, U_32 mapLength, 
                                   const AddrLocation* addrLocationMap, 
                                   const void* compileInfo)
 {
@@ -575,7 +575,7 @@
     // convert AddrLocation[] to jvmtiAddrLocationMap[]
     jvmtiAddrLocationMap* jvmtiLocationMap = (jvmtiAddrLocationMap*) 
             STD_MALLOC( mapLength * sizeof(jvmtiAddrLocationMap) );
-    for (uint32 i = 0; i < mapLength; i++) {
+    for (U_32 i = 0; i < mapLength; i++) {
         jlocation location = (jlocation) addrLocationMap[i].location;
 
         if (location == 65535)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp Thu May 22 06:33:38 2008
@@ -144,7 +144,7 @@
 #else // _IA32_ & _EM64T_
 
 // requires stack iterator and buffer to save intermediate information
-static void jvmti_jit_prepare_pop_frame(StackIterator* si, uint32* buf) {
+static void jvmti_jit_prepare_pop_frame(StackIterator* si, U_32* buf) {
     CTRACE(("Prepare PopFrame for JIT"));
     // pop native frame
     assert(si_is_native(si));
@@ -221,7 +221,7 @@
     CTRACE(("PopFrame prepare for method IP: %p", si_get_ip(si) ));
 
     // prepare pop frame - find regs values
-    uint32 buf = 0;
+    U_32 buf = 0;
     jvmti_jit_prepare_pop_frame(si, &buf);
 
     // save regs value from jit context to m2n
@@ -309,7 +309,7 @@
     si_transfer_all_preserved_registers(si);
 
     // prepare pop frame - find regs values
-    uint32 buf = 0;
+    U_32 buf = 0;
     jvmti_jit_prepare_pop_frame(si, &buf);
 
     // relocate single step breakpoints

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_roots.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_roots.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_roots.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_roots.cpp Thu May 22 06:33:38 2008
@@ -215,7 +215,7 @@
 }
 
 static void ti_add_compressed_root_set_entry(
-        uint32 *ref, 
+        U_32 *ref, 
         Boolean UNREF pinned)
 {
     assert(REFS_IS_COMPRESSED_MODE);
@@ -347,7 +347,7 @@
     void (*save_gc_add_root_set_entry_interior_pointer)
         (void **slot, int offset, Boolean pinned);
     void (*save_gc_add_compressed_root_set_entry)
-        (uint32 *ref, Boolean pinned);
+        (U_32 *ref, Boolean pinned);
 
     // save away old values
     save_gc_add_root_set_entry =

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp Thu May 22 06:33:38 2008
@@ -51,7 +51,7 @@
     jint depth;
 
     /** number of inlines in current si frame */
-    uint32 inlined_num;
+    U_32 inlined_num;
 
     /** index of inlined frame in current si frame */
     int inlined_depth;
@@ -160,7 +160,7 @@
         uint16 bc;
         // inlined method frame
         if (0 != inlined_depth) {
-            uint32 offset = (uint32) ((char*) ip -
+            U_32 offset = (U_32) ((char*) ip -
                 (char*) cci->get_code_block_addr());
             method = jit->get_inlined_method(
                 cci->get_inline_info(), offset, inlined_depth);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp Thu May 22 06:33:38 2008
@@ -600,7 +600,7 @@
             ip = (NativeCodePtr)((POINTER_SIZE_INT)ip + stub_disasm.get_length_with_prefix());
             stub_disasm = ip;
 #endif
-            // Now IP points on mov(stub, ecx_opnd, Imm_Opnd((int32)method));
+            // Now IP points on mov(stub, ecx_opnd, Imm_Opnd((I_32)method));
             // where method is the method handle. Need to get its
             // address from instruction, it is an immd operand in mov
             assert(stub_disasm.get_operands_count() == 1);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/lil_code_generator_em64t.cpp Thu May 22 06:33:38 2008
@@ -346,7 +346,7 @@
             if (fp_param_cnt < LcgEM64TContext::MAX_FR_OUTPUTS) {
                 if (take_inputs_from_stack) {
                     // compute rsp-relative offset of the bottom of FR save area
-                    int32 offset = context.get_input_fr_save_offset() +
+                    I_32 offset = context.get_input_fr_save_offset() +
                         fp_param_cnt * LcgEM64TContext::FR_SIZE;
                     return new(mem) LcgEM64TLoc(LLK_FStk, offset);
                 } else {
@@ -361,7 +361,7 @@
                     ? (fp_param_cnt - LcgEM64TContext::MAX_FR_OUTPUTS)
                     * LcgEM64TContext::FR_SIZE : 0;
                 // compute rsp-relative offset of the top of the activation frame
-                int32 offset = context.get_stk_size();
+                I_32 offset = context.get_stk_size();
                 // skip rip
                 offset += LcgEM64TContext::GR_SIZE;
                 // skip size allocated for preceding inputs
@@ -375,7 +375,7 @@
             if (gp_param_cnt < LcgEM64TContext::MAX_GR_OUTPUTS) {
                 if (take_inputs_from_stack) {
                     // compute rsp-relative offset of the bottom of GR save area
-                    int32 offset = context.get_input_gr_save_offset() +
+                    I_32 offset = context.get_input_gr_save_offset() +
                         gp_param_cnt * LcgEM64TContext::GR_SIZE;
                     return new(mem) LcgEM64TLoc(LLK_GStk, offset);
                 } else {
@@ -390,7 +390,7 @@
                     ? (fp_param_cnt - LcgEM64TContext::MAX_FR_OUTPUTS)
                     * LcgEM64TContext::FR_SIZE : 0;
                 // compute rsp-relative offset of the top of the activation frame
-                int32 offset = context.get_stk_size();
+                I_32 offset = context.get_stk_size();
                 // skip rip
                 offset += LcgEM64TContext::GR_SIZE;
                 // skip size allocated for preceding inputs
@@ -438,7 +438,7 @@
                 unsigned fp_on_stack = fp_param_cnt > LcgEM64TContext::MAX_FR_OUTPUTS
                     ? (fp_param_cnt - LcgEM64TContext::MAX_FR_OUTPUTS)
                     * LcgEM64TContext::FR_SIZE : 0;
-                int32 offset = gp_on_stack;
+                I_32 offset = gp_on_stack;
 #ifndef _WIN64
                 offset += fp_on_stack;
 #endif
@@ -455,7 +455,7 @@
                 unsigned fp_on_stack = fp_param_cnt > LcgEM64TContext::MAX_FR_OUTPUTS
                     ? (fp_param_cnt - LcgEM64TContext::MAX_FR_OUTPUTS)
                     * LcgEM64TContext::FR_SIZE : 0;
-                int32 offset = gp_on_stack;
+                I_32 offset = gp_on_stack;
 #ifndef _WIN64
                 offset += fp_on_stack;
 #endif
@@ -546,7 +546,7 @@
     inline const M_Opnd & get_m_opnd(const LcgEM64TLoc * loc) const {
         assert(loc->kind == LLK_GStk || loc->kind == LLK_FStk);
         void * const mem_ptr = mem.alloc(sizeof(M_Base_Opnd));
-        return *(new(mem_ptr) M_Base_Opnd(rsp_reg, (int32)loc->addr));
+        return *(new(mem_ptr) M_Base_Opnd(rsp_reg, (I_32)loc->addr));
     }
 
     inline const RM_Opnd & get_rm_opnd(const LcgEM64TLoc * loc) const {
@@ -558,7 +558,7 @@
         return get_m_opnd(loc);
     }
 
-    inline void adjust_stack_pointer(int32 offset) {
+    inline void adjust_stack_pointer(I_32 offset) {
         if (offset != 0) {
             buf = alu(buf, add_opc, rsp_opnd, get_imm_opnd(offset), size_64);
         }
@@ -626,7 +626,7 @@
         }
     }
 
-    void shift_op_imm_rm(const LcgEM64TLoc * dest, int32 imm_val, const LcgEM64TLoc * src) {
+    void shift_op_imm_rm(const LcgEM64TLoc * dest, I_32 imm_val, const LcgEM64TLoc * src) {
         assert(dest->kind == LLK_Gr || dest->kind == LLK_GStk);
         assert(src->kind == LLK_Gr || src->kind == LLK_GStk);
         // this code sequence can be optimized if dest is located in memory
@@ -634,7 +634,7 @@
         bin_op_rm_rm(LO_Shl, dest, dest, src);
     }
 
-    void shift_op_rm_imm(const LcgEM64TLoc * dest, const LcgEM64TLoc * src, int32 imm_val) {
+    void shift_op_rm_imm(const LcgEM64TLoc * dest, const LcgEM64TLoc * src, I_32 imm_val) {
         const Imm_Opnd & imm = get_imm_opnd(imm_val);
         if (src->kind == LLK_Gr) {
         if (dest->kind == LLK_Gr) {
@@ -660,7 +660,7 @@
 
     // subtract op where the first op is immediate
     // (allowed only for intefer values)
-    void sub_op_imm_rm(const LcgEM64TLoc * dest, int32 imm_val, const LcgEM64TLoc * src) {
+    void sub_op_imm_rm(const LcgEM64TLoc * dest, I_32 imm_val, const LcgEM64TLoc * src) {
         assert(dest->kind == LLK_Gr || dest->kind == LLK_GStk);
         assert(src->kind == LLK_Gr || src->kind == LLK_GStk);
         // TODO: this code sequence can be optimized if dest is located in memory
@@ -668,7 +668,7 @@
     }
 
     void alu_op_rm_imm(const ALU_Opcode alu_opc, const LcgEM64TLoc * dest,
-                       const LcgEM64TLoc * src, int32 imm_val) {
+                       const LcgEM64TLoc * src, I_32 imm_val) {
         assert(alu_opc < n_alu);
         assert(dest->kind == LLK_Gr || dest->kind == LLK_GStk);
         assert(src->kind == LLK_Gr || src->kind == LLK_GStk);
@@ -733,7 +733,7 @@
 
     // where the second operand is immediate (allowed only for integer values!)
     void bin_op_rm_imm(LilOperation o, const LcgEM64TLoc* dest,
-                       const LcgEM64TLoc* src, int32 imm_val) {
+                       const LcgEM64TLoc* src, I_32 imm_val) {
         assert(dest->kind == LLK_Gr || dest->kind == LLK_GStk);
         assert(src->kind == LLK_Gr || src->kind == LLK_GStk);
 
@@ -887,7 +887,7 @@
                 return *(new(M_Index_Opnd_mem) M_Index_Opnd(
                     base_loc != NULL ? get_r_opnd(base_loc).reg_no() : n_reg,
                     index_loc != NULL ?  get_r_opnd(index_loc).reg_no() : n_reg,
-                    (uint32)offset, scale));
+                    (U_32)offset, scale));
         }
 
         // check if it's enough to use only one temporary register
@@ -896,13 +896,13 @@
                 buf = mov(buf, tmp_reg, get_m_opnd(base_loc), size_64);
                 return *(new(M_Index_Opnd_mem) M_Index_Opnd(tmp_reg.reg_no(),
                     index_loc != NULL ?  get_r_opnd(index_loc).reg_no() : n_reg,
-                    (uint32)offset, scale));
+                    (U_32)offset, scale));
             }
             if (is_index_in_mem) {
                 buf = mov(buf, tmp_reg, get_m_opnd(index_loc), size_64);
                 return *(new(M_Index_Opnd_mem) M_Index_Opnd(
                     base_loc != NULL ? get_r_opnd(base_loc).reg_no() : n_reg,
-                    tmp_reg.reg_no(), (uint32)offset, scale));
+                    tmp_reg.reg_no(), (U_32)offset, scale));
             }
             DIE(("Should never reach this point"));
         }
@@ -911,7 +911,7 @@
         const LcgEM64TLoc * ret_loc =
             new(mem) LcgEM64TLoc(LLK_Gr, LcgEM64TContext::get_index_in_map(tmp_reg.reg_no()));
         if (index_loc != NULL) {
-            int32 shift = scale / 4 + 1;
+            I_32 shift = scale / 4 + 1;
             bin_op_rm_imm(LO_Shl, ret_loc, index_loc, shift);
             if (base_loc != NULL) {
                 bin_op_rm_rm(LO_Add, ret_loc, ret_loc, base_loc);
@@ -939,7 +939,7 @@
             move_imm(ret_loc, offset);
             offset = 0;
         }
-        return *(new(M_Index_Opnd_mem) M_Base_Opnd(get_r_opnd(ret_loc).reg_no(), (uint32)offset));
+        return *(new(M_Index_Opnd_mem) M_Base_Opnd(get_r_opnd(ret_loc).reg_no(), (U_32)offset));
     }
 
     // sets up stack frame
@@ -980,7 +980,7 @@
         }  
 
         // compute the rsp-relative offset of the top of the GR save area
-        int32 offset = (int32)context.get_input_gr_save_offset() +
+        I_32 offset = (I_32)context.get_input_gr_save_offset() +
             context.get_stk_input_gr_save_size();
         // store GR inputs to the computed locations
         for (int i = context.get_num_gr_inputs() - 1; i >= 0; i--) {
@@ -991,7 +991,7 @@
             buf = mov(buf, dest, r_opnd);
         }
         // compute the rsp-relative offset of the top of the FR save area
-        offset = (int32)context.get_input_fr_save_offset() +
+        offset = (I_32)context.get_input_fr_save_offset() +
             context.get_stk_input_fr_save_size();
         // store FR inputs to the computed locations
         for (int i = context.get_num_fr_inputs() - 1; i >= 0; i--) {
@@ -1010,7 +1010,7 @@
             return;
         }
         // compute the rsp-relative offset of the bottom of the FR save area
-        int32 offset = (int32)context.get_input_fr_save_offset();
+        I_32 offset = (I_32)context.get_input_fr_save_offset();
         // restore FR inputs
         for (unsigned i = 0; i < context.get_num_fr_inputs(); i++) {
             const XMM_Opnd & r_opnd =
@@ -1020,7 +1020,7 @@
             offset += LcgEM64TContext::FR_SIZE;
         }
         // compute the rsp-relative offset of the bottom of the GR save area
-        offset = (int32)context.get_input_gr_save_offset();
+        offset = (I_32)context.get_input_gr_save_offset();
         // restore GR inputs
         for (unsigned i = 0; i < context.get_num_gr_inputs(); i++) {
             const R_Opnd & r_opnd =
@@ -1147,7 +1147,7 @@
     }
 
     void alloc(LilVariable * var, unsigned sz) {
-        int32 alloc_offset = context.get_alloc_start_offset() + current_alloc;
+        I_32 alloc_offset = context.get_alloc_start_offset() + current_alloc;
         // the actual size allocated will always be a multiple of 8
         current_alloc += align_8(sz);
         // var = sp + alloc_offset
@@ -1174,10 +1174,10 @@
             if (lil_operand_is_immed(op1) && lil_operand_is_immed(op2)) {
                 // type-convert to get signed types of same length
                 assert(fit32(get_imm_value(op1)));
-                int32 op1_imm = (int32)get_imm_value(op1);
+                I_32 op1_imm = (I_32)get_imm_value(op1);
                 assert(fit32(get_imm_value(op2)));
-                int32 op2_imm = (int32)get_imm_value(op2); 
-                int32 result = 0;
+                I_32 op2_imm = (I_32)get_imm_value(op2); 
+                I_32 result = 0;
                 switch (o) {
                 case LO_Add:
                     result = op1_imm + op2_imm;
@@ -1197,7 +1197,7 @@
                 move_imm(dest_loc, result);
             } else if (lil_operand_is_immed(op1)) {
                 assert(fit32(get_imm_value(op1)));
-                const int32 op1_imm = (int32)get_imm_value(op1);
+                const I_32 op1_imm = (I_32)get_imm_value(op1);
                 const LcgEM64TLoc * op2_loc = get_op_loc(op2, false);
                 switch (o) {
                 case LO_Add:
@@ -1217,7 +1217,7 @@
             } else if (lil_operand_is_immed(op2)) {
                 const LcgEM64TLoc*  op1_loc = get_op_loc(op1, false);
                 assert(fit32(get_imm_value(op2)));
-                const int32 op2_imm = (int32)get_imm_value(op2);
+                const I_32 op2_imm = (I_32)get_imm_value(op2);
                 bin_op_rm_imm(o, dest_loc, op1_loc, op2_imm);
             } else {  // both operands non-immediate
                 const LcgEM64TLoc * src1_loc = get_op_loc(op1, false);
@@ -1227,8 +1227,8 @@
         } else { // unary operation
             if (lil_operand_is_immed(op1)) {
                 assert(fit32(get_imm_value(op1)));
-                int32 imm = (int32)get_imm_value(op1);
-                int32 result = 0;
+                I_32 imm = (I_32)get_imm_value(op1);
+                I_32 result = 0;
                 switch (o) {
                 case LO_Neg:
                     result = -imm;
@@ -1237,22 +1237,22 @@
                     result = ~imm;
                     break;
                 case LO_Sx1:
-                    result = (int32) (int8) imm;
+                    result = (I_32) (int8) imm;
                     break;
                 case LO_Sx2:
-                    result = (int32) (int16) imm;
+                    result = (I_32) (int16) imm;
                     break;
                 case LO_Sx4:
-                    result = (int32) (int32) imm;
+                    result = (I_32) (I_32) imm;
                     break;
                 case LO_Zx1:
-                    result = (int32) (uint64) (uint8) imm;
+                    result = (I_32) (uint64) (uint8) imm;
                     break;
                 case LO_Zx2:
-                    result = (int32) (uint64) (uint16) imm;
+                    result = (I_32) (uint64) (uint16) imm;
                     break;
                 case LO_Zx4:
-                    result = (int32) (uint64) (uint32) imm;
+                    result = (I_32) (uint64) (U_32) imm;
                     break;
                 default:
                     DIE(("Unexpected operation"));  // control should never reach this point
@@ -1669,7 +1669,7 @@
         take_inputs_from_stack = true;
 
         // rsp-relative offset of the top of the m2n frame
-        int32 offset = context.get_m2n_offset() + context.get_stk_m2n_size();
+        I_32 offset = context.get_m2n_offset() + context.get_stk_m2n_size();
 
         buf = m2n_gen_push_m2n(buf, method, current_frame_type, handles,
             lil_cs_get_max_locals(cs), lil_ic_get_num_std_places(ic), offset);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t.cpp Thu May 22 06:33:38 2008
@@ -283,7 +283,7 @@
                         bool handles,
                         unsigned num_callee_saves,
                         unsigned num_std_need_to_save,
-                        int32 bytes_to_m2n_top) {
+                        I_32 bytes_to_m2n_top) {
     // skip callee-saves registers
     bytes_to_m2n_top -= num_callee_saves * LcgEM64TContext::GR_SIZE;
     // TODO: check if it makes sense to save all callee-saves registers here
@@ -324,7 +324,7 @@
         num_std_need_to_save, 0);
     
     // shift to the last_m2n_frame field
-    int32 last_m2n_frame_offset = (int32)(int64)&((VM_thread*)0)->last_m2n_frame;
+    I_32 last_m2n_frame_offset = (I_32)(int64)&((VM_thread*)0)->last_m2n_frame;
     buf = alu(buf, add_opc,  rax_opnd,  Imm_Opnd(size_32, last_m2n_frame_offset), size_64);
     // store pointer to pointer to last m2n frame
     bytes_to_m2n_top -= LcgEM64TContext::GR_SIZE;
@@ -367,7 +367,7 @@
 }
 
 char * m2n_gen_pop_m2n(char * buf, bool handles, unsigned num_callee_saves,
-                      int32 bytes_to_m2n_bottom, unsigned num_preserve_ret) {
+                      I_32 bytes_to_m2n_bottom, unsigned num_preserve_ret) {
     assert (num_preserve_ret <= 2);
     assert(LcgEM64TContext::GR_SIZE == 8);
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t_internal.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t_internal.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t_internal.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/m2n_em64t_internal.h Thu May 22 06:33:38 2008
@@ -111,7 +111,7 @@
                            Negative value means that current rsp is above m2n bottom.
  */
 char * m2n_gen_push_m2n(char * buf, Method_Handle method, frame_type current_frame_type, bool handles,
-                        unsigned num_callee_saves, unsigned num_std_need_to_save, int32 bytes_to_m2n_top);
+                        unsigned num_callee_saves, unsigned num_std_need_to_save, I_32 bytes_to_m2n_top);
 unsigned m2n_push_m2n_size(unsigned num_callee_saves, unsigned num_std_need_to_save);
 
 /**
@@ -124,7 +124,7 @@
  * @param handles As for push_m2n, frees the handles if true.
  */
 char * m2n_gen_pop_m2n(char * buf, bool handles, unsigned num_callee_saves,
-                       int32 bytes_to_m2n_bottom, unsigned preserve_ret);
+                       I_32 bytes_to_m2n_bottom, unsigned preserve_ret);
 unsigned m2n_pop_m2n_size(bool handles, unsigned num_callee_saves, unsigned preserve_ret);
 
 // returns top of the specified frame on the stack (it should point to return ip)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/stack_iterator_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/stack_iterator_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/stack_iterator_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/em64t/stack_iterator_em64t.cpp Thu May 22 06:33:38 2008
@@ -135,7 +135,7 @@
 {
     char* patch_offset = NULL;
 
-    ss = mov(ss, dst,  M_Base_Opnd(base, (int32)offset));
+    ss = mov(ss, dst,  M_Base_Opnd(base, (I_32)offset));
 
     if (check_null)
     {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32.cpp Thu May 22 06:33:38 2008
@@ -89,7 +89,7 @@
 // 20040708 New function - needs proper implementation.
 void m2n_set_ip(M2nFrame* lm2nf, NativeCodePtr ip)
 {
-    lm2nf->eip = (uint32)ip;
+    lm2nf->eip = (U_32)ip;
 } 
 
 Method_Handle m2n_get_method(M2nFrame* m2nf)
@@ -146,7 +146,7 @@
 }
 
 bool m2n_is_suspended_frame(M2nFrame * m2nf) {
-    return (uint32)m2nf->p_lm2nf == 1;
+    return (U_32)m2nf->p_lm2nf == 1;
 
 }
 
@@ -157,9 +157,9 @@
 
 //***** Stub Interface
 
-uint32* m2n_get_args(M2nFrame* m2nf)
+U_32* m2n_get_args(M2nFrame* m2nf)
 {
-    return (uint32*)&m2nf->regs;
+    return (U_32*)&m2nf->regs;
 }
 
 unsigned m2n_ts_to_register_size()

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32_internal.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32_internal.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32_internal.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/m2n_ia32_internal.h Thu May 22 06:33:38 2008
@@ -35,7 +35,7 @@
 class R_Opnd;
 
 // Return a pointer to the argument just above the return address of an M2nFrame
-uint32* m2n_get_args(M2nFrame*);
+U_32* m2n_get_args(M2nFrame*);
 
 // An M2nFrame is a structure that resides on the stack.
 // It takes up space below and including the return address to the managed code, and thus is immediately below the arguments.
@@ -97,11 +97,11 @@
     Method_Handle        method;
     frame_type           current_frame_type; // type of the current frame also shows is the frame unwindable
     Registers*           pop_regs; // This is only for M2nFrames for suspended managed code (as against ones that call stubs and prepare jvmtiPopFrame)
-    uint32               edi;
-    uint32               esi;
-    uint32               ebx;
-    uint32               ebp;
-    uint32               eip;
+    U_32               edi;
+    U_32               esi;
+    U_32               ebx;
+    U_32               ebp;
+    U_32               eip;
     Registers*           regs; // This is only for M2nFrames for suspended managed code (as against ones that call stubs and prepare jvmtiPopFrame)
 };
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/stack_iterator_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/stack_iterator_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/stack_iterator_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ia32/stack_iterator_ia32.cpp Thu May 22 06:33:38 2008
@@ -53,7 +53,7 @@
     CodeChunkInfo*    cci;
     JitFrameContext   c;
     M2nFrame*         m2nfl;
-    uint32            ip;
+    U_32            ip;
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -76,7 +76,7 @@
     CTRACE(("si_unwind_from_m2n, ip = %p",(void*)m2nfl->eip));
 
     // Is it a normal M2nFrame or one for suspended managed code?
-    if ((uint32)m2nfl->p_lm2nf==1) {
+    if ((U_32)m2nfl->p_lm2nf==1) {
         // Suspended managed code, eip is at instruction, esp & registers are in regs structure
         CTRACE(("si_unwind_from_m2n from suspended managed code, ip = %p", 
             (void*)m2nfl->regs->eip));
@@ -106,7 +106,7 @@
         si->c.eflags = m2nfl->pop_regs->eflags;
     } else {
         // Normal M2nFrame, eip is past instruction, esp is implicitly address just beyond the frame, callee saves registers in M2nFrame
-        si->c.esp   = (uint32)m2nfl + m2n_sizeof_m2n_frame;
+        si->c.esp   = (U_32)m2nfl + m2n_sizeof_m2n_frame;
         si->c.p_eip = &m2nfl->eip;
         si->c.is_ip_past = TRUE;
         si->c.p_edi = &m2nfl->edi;
@@ -394,9 +394,9 @@
 void si_set_ip(StackIterator* si, NativeCodePtr ip, bool also_update_stack_itself)
 {
     if (also_update_stack_itself) {
-        *(si->c.p_eip) = (uint32)ip;
+        *(si->c.p_eip) = (U_32)ip;
     } else {
-        si->ip = (uint32)ip;
+        si->ip = (U_32)ip;
         si->c.p_eip = &si->ip;
     }
 }
@@ -438,7 +438,7 @@
 
 void si_set_return_pointer(StackIterator* si, void** return_value)
 {
-    si->c.p_eax = (uint32*)return_value;
+    si->c.p_eax = (U_32*)return_value;
 }
 
 #ifdef _WIN32
@@ -505,13 +505,13 @@
     memcpy(&local_si, si, sizeof(StackIterator));
 
     if (NULL == si->c.p_eax)
-        local_si.c.p_eax = (uint32*)&null_pointer;
+        local_si.c.p_eax = (U_32*)&null_pointer;
     if (NULL == si->c.p_ebx)
-        local_si.c.p_ebx = (uint32*)&null_pointer;
+        local_si.c.p_ebx = (U_32*)&null_pointer;
     if (NULL == si->c.p_ecx)
-        local_si.c.p_ecx = (uint32*)&null_pointer;
+        local_si.c.p_ecx = (U_32*)&null_pointer;
     if (NULL == si->c.p_edx)
-        local_si.c.p_edx = (uint32*)&null_pointer;
+        local_si.c.p_edx = (U_32*)&null_pointer;
 
     if (si->c.p_eip == &si->ip)
         local_si.c.p_eip = &local_si.ip;
@@ -531,7 +531,7 @@
     tcs(&local_si);
 }
 
-inline static uint32 unref_reg(uint32* p_reg) {
+inline static U_32 unref_reg(U_32* p_reg) {
     return p_reg ? *p_reg : 0;
 }
 void si_copy_to_registers(StackIterator* si, Registers* regs)
@@ -552,8 +552,8 @@
 
 void si_set_callback(StackIterator* si, NativeCodePtr* callback) {
     si->c.esp = si->c.esp - 4;
-    *((uint32*) si->c.esp) = *(si->c.p_eip);
-    si->c.p_eip = ((uint32*)callback);
+    *((U_32*) si->c.esp) = *(si->c.p_eip);
+    si->c.p_eip = ((U_32*)callback);
 }
 
 void si_reload_registers()

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/ipf/lil_code_generator_ipf.cpp Thu May 22 06:33:38 2008
@@ -1592,7 +1592,7 @@
                     result = (int64) (int16) imm;
                     break;
                 case LO_Sx4:
-                    result = (int64) (int32) imm;
+                    result = (int64) (I_32) imm;
                     break;
                 case LO_Zx1:
                     result = (int64) (uint64) (uint8) imm;
@@ -1601,7 +1601,7 @@
                     result = (int64) (uint64) (uint16) imm;
                     break;
                 case LO_Zx4:
-                    result = (int64) (uint64) (uint32) imm;
+                    result = (int64) (uint64) (U_32) imm;
                     break;
                 default:
                     DIE(("Unexpected LIL operation"));  // control should never reach this point

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/lil_code_generator_utils.cpp Thu May 22 06:33:38 2008
@@ -114,13 +114,13 @@
         *(int8*)patch->addr = (int8)diff;
         break;
     case LPT_Rel32:
-        diff = (int64)((char *)label_adress->addr - (char *)((int32 *)patch->addr + 1));
-        assert(diff == (int64)(int32)diff);
-        *(int32*)patch->addr = (int32)diff;
+        diff = (int64)((char *)label_adress->addr - (char *)((I_32 *)patch->addr + 1));
+        assert(diff == (int64)(I_32)diff);
+        *(I_32*)patch->addr = (I_32)diff;
         break;
     case LPT_Abs32:
         assert((POINTER_SIZE_INT)label_adress->addr <= 0xFFFFffff);
-        *(int32*)patch->addr = (int32)(POINTER_SIZE_INT)label_adress->addr;
+        *(I_32*)patch->addr = (I_32)(POINTER_SIZE_INT)label_adress->addr;
         break;
     default:
         DIE(("Unknown patch typ"));

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/m2n.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/m2n.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/m2n.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/m2n.cpp Thu May 22 06:33:38 2008
@@ -21,14 +21,14 @@
 
 #include "m2n.h"
 
-const uint32 FRAME_UNKNOWN = 0x00;
-const uint32 FRAME_NON_UNWINDABLE = 0x80;
-const uint32 FRAME_JNI = 0x01 | FRAME_NON_UNWINDABLE;
-const uint32 FRAME_COMPILATION = 0x02 | FRAME_NON_UNWINDABLE;
-const uint32 FRAME_UNPOPABLE = 0x0000;
-const uint32 FRAME_POPABLE = 0x0100;
-const uint32 FRAME_POP_NOW = 0x0200;
-const uint32 FRAME_POP_DONE = FRAME_POPABLE | FRAME_POP_NOW;
-const uint32 FRAME_POP_MASK = 0x0700;
-const uint32 FRAME_SAFE_POINT = 0x0800;
-const uint32 FRAME_MODIFIED_STACK = 0x1000;
+const U_32 FRAME_UNKNOWN = 0x00;
+const U_32 FRAME_NON_UNWINDABLE = 0x80;
+const U_32 FRAME_JNI = 0x01 | FRAME_NON_UNWINDABLE;
+const U_32 FRAME_COMPILATION = 0x02 | FRAME_NON_UNWINDABLE;
+const U_32 FRAME_UNPOPABLE = 0x0000;
+const U_32 FRAME_POPABLE = 0x0100;
+const U_32 FRAME_POP_NOW = 0x0200;
+const U_32 FRAME_POP_DONE = FRAME_POPABLE | FRAME_POP_NOW;
+const U_32 FRAME_POP_MASK = 0x0700;
+const U_32 FRAME_SAFE_POINT = 0x0800;
+const U_32 FRAME_MODIFIED_STACK = 0x1000;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/stack_iterator.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/stack_iterator.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/stack_iterator.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/lil/stack_iterator/stack_iterator.cpp Thu May 22 06:33:38 2008
@@ -36,7 +36,7 @@
         return m2n_get_method(si_get_m2n(si));
 }
 
-uint32 si_get_inline_depth(StackIterator* si)
+U_32 si_get_inline_depth(StackIterator* si)
 {
     //
     // Here we assume that JIT data blocks can store only InlineInfo
@@ -60,7 +60,7 @@
         return cci->get_jit()->get_inline_depth(
                 cci->get_inline_info(),
                 // FIXME64: no support for large methods
-                (uint32)((POINTER_SIZE_INT)si_get_ip(si) - (POINTER_SIZE_INT)cci->get_code_block_addr()));
+                (U_32)((POINTER_SIZE_INT)si_get_ip(si) - (POINTER_SIZE_INT)cci->get_code_block_addr()));
     }
     return 0;
 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_em64t.cpp Thu May 22 06:33:38 2008
@@ -34,7 +34,7 @@
     uint16  ss;
     uint16  cs;
     uint64  rip;
-    uint32  eflags;
+    U_32  eflags;
 };
 
 #define REGSIZE(_field_) ((jint)sizeof(((NcaiRegisters*)0)->_field_))

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/ncai/utils/ncai_utils_ia32.cpp Thu May 22 06:33:38 2008
@@ -14,22 +14,22 @@
 
 struct NcaiRegisters
 {
-    uint32  eax;
-    uint32  ebx;
-    uint32  ecx;
-    uint32  edx;
-    uint32  esp;
-    uint32  ebp;
-    uint32  esi;
-    uint32  edi;
+    U_32  eax;
+    U_32  ebx;
+    U_32  ecx;
+    U_32  edx;
+    U_32  esp;
+    U_32  ebp;
+    U_32  esi;
+    U_32  edi;
     uint16  ds;
     uint16  es;
     uint16  fs;
     uint16  gs;
     uint16  ss;
     uint16  cs;
-    uint32  eip;
-    uint32  eflags;
+    U_32  eip;
+    U_32  eflags;
 };
 
 #define REGSIZE(_field_) ((jint)sizeof(((NcaiRegisters*)0)->_field_))

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/object_handles.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/object_handles.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/object_handles.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/object_handles.cpp Thu May 22 06:33:38 2008
@@ -295,7 +295,7 @@
     assert(n);
     memset(n, 0, size);
 #ifdef _IPF_
-    n->capacity = (uint32)capacity;
+    n->capacity = (U_32)capacity;
 #else //IA32
     n->capacity = (uint16)capacity;
 #endif //IA32

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/object/vm_arrays.cpp Thu May 22 06:33:38 2008
@@ -416,7 +416,7 @@
 
 // This implementation may be Java specific
 
-ArrayCopyResult array_copy(ManagedObject *src, int32 srcOffset, ManagedObject *dst, int32 dstOffset, int32 length)
+ArrayCopyResult array_copy(ManagedObject *src, I_32 srcOffset, ManagedObject *dst, I_32 dstOffset, I_32 length)
 {
     if (src == ((ManagedObject *)VM_Global_State::loader_env->managed_null) ||
         dst == ((ManagedObject *)VM_Global_State::loader_env->managed_null)) {
@@ -444,8 +444,8 @@
     // We haven't determined at this point the types of arrays, but the
     // length is always at the same offset from the start of the array, so we
     // safely cast the pointers to any array type to get the lengths.
-    int32 src_length = get_vector_length((Vector_Handle)src);
-    int32 dst_length = get_vector_length((Vector_Handle)dst);
+    I_32 src_length = get_vector_length((Vector_Handle)src);
+    I_32 dst_length = get_vector_length((Vector_Handle)dst);
     if((srcOffset + length) > src_length || (dstOffset + length) > dst_length)
        return ACR_BadIndices;
 
@@ -512,7 +512,7 @@
 #endif // VM_STATS
         memmove(get_vector_element_address_int32(dst, dstOffset),
                 get_vector_element_address_int32(src, srcOffset),
-                length * sizeof(int32));
+                length * sizeof(I_32));
         break;
     case 'J':
 #ifdef VM_STATS

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/stack/stack_trace.cpp Thu May 22 06:33:38 2008
@@ -72,7 +72,7 @@
     POINTER_SIZE_INT eff_ip = (POINTER_SIZE_INT)ip -
                                 (is_ip_past ? callLength : 0);
 
-    uint32 offset = 0;
+    U_32 offset = 0;
     if (depth < 0) // Not inlined method
     {
         if (cci->get_jit()->get_bc_location_for_native(
@@ -85,7 +85,7 @@
 
         if (inl_info)
         {
-            offset = (uint32) ((POINTER_SIZE_INT)ip -
+            offset = (U_32) ((POINTER_SIZE_INT)ip -
                 (POINTER_SIZE_INT)cci->get_code_block_addr());
             bcOffset = cci->get_jit()->get_inlined_bc(inl_info, offset, depth);
         }
@@ -126,7 +126,7 @@
         stf->method = si_get_method(si);
         stf->depth = -1;
         if (stf->method) {
-            uint32 inlined_depth = si_get_inline_depth(si);
+            U_32 inlined_depth = si_get_inline_depth(si);
             if ( (target_depth >= depth) && 
                  (target_depth <= depth + inlined_depth) ) {
                 stf->ip = si_get_ip(si);
@@ -136,7 +136,7 @@
                     CodeChunkInfo* cci = si_get_code_chunk_info(si);
                     // FIXME64: no support for large methods
                     // with compiled code size greater than 4GB
-                    uint32 offset = (uint32)((POINTER_SIZE_INT)stf->ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
+                    U_32 offset = (U_32)((POINTER_SIZE_INT)stf->ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
                     stf->depth = inlined_depth - (target_depth - depth);
                     stf->method = cci->get_jit()->get_inlined_method(
                             cci->get_inline_info(), offset, stf->depth);
@@ -209,11 +209,11 @@
                 if (cci->has_inline_info()) {
                     // FIXME64: no support for large methods
                     // with compiled code greater than 4GB
-                    uint32 offset = (uint32)((POINTER_SIZE_INT)ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
-                    uint32 inlined_depth = jit->get_inline_depth(
+                    U_32 offset = (U_32)((POINTER_SIZE_INT)ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
+                    U_32 inlined_depth = jit->get_inline_depth(
                         cci->get_inline_info(), offset);
                     if (inlined_depth) {
-                        for (uint32 i = inlined_depth; i > 0; i--) {
+                        for (U_32 i = inlined_depth; i > 0; i--) {
                             stf->method = jit->get_inlined_method(cci->get_inline_info(), offset, i);
                             stf->ip = ip;
                             stf->depth = i;
@@ -316,11 +316,11 @@
             if (cci != NULL && cci->has_inline_info()) {
                 // FIXME64: no support for large methods
                 // with compiled code size greater than 4GB
-                uint32 offset = (uint32)((POINTER_SIZE_INT)si_get_ip(si) - (POINTER_SIZE_INT)cci->get_code_block_addr());
-                uint32 inlined_depth = cci->get_jit()->get_inline_depth(
+                U_32 offset = (U_32)((POINTER_SIZE_INT)si_get_ip(si) - (POINTER_SIZE_INT)cci->get_code_block_addr());
+                U_32 inlined_depth = cci->get_jit()->get_inline_depth(
                     cci->get_inline_info(), offset);
                 if (inlined_depth) {
-                    for (uint32 i = inlined_depth; i > 0; i--) {
+                    for (U_32 i = inlined_depth; i > 0; i--) {
                         Method *real_method = cci->get_jit()->get_inlined_method(cci->get_inline_info(), offset, i);
                         fprintf(f, "%s.%s%s\n", real_method->get_class()->get_name()->bytes, 
                             real_method->get_name()->bytes, real_method->get_descriptor()->bytes);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/atomics_common.cpp Thu May 22 06:33:38 2008
@@ -43,8 +43,8 @@
 
     bool result =
         (apr_atomic_cas32(
-            (uint32*)p_slot, (uint32)compressed_value, (uint32)compressed_expected)
-        == (uint32)compressed_expected);
+            (U_32*)p_slot, (U_32)compressed_value, (U_32)compressed_expected)
+        == (U_32)compressed_expected);
 
     // TODO: uncomment foolowing line for GC
     //INTERNAL(gc_write_barrier) (p_base_of_object_with_slot);
@@ -145,7 +145,7 @@
     U_8* java_ref = (U_8*)h->object;
     jint* field_addr = (jint*)(java_ref + offset);
     bool result =
-      (apr_atomic_cas32((uint32*)field_addr, (uint32)value, (uint32)expected) == (uint32)expected);
+      (apr_atomic_cas32((U_32*)field_addr, (U_32)value, (U_32)expected) == (U_32)expected);
 
     tmn_suspend_enable();
     return (jboolean)(result?JNI_TRUE:JNI_FALSE);
@@ -240,7 +240,7 @@
             index);
 
     bool result =
-      (apr_atomic_cas32((uint32 *)field_addr, (uint32)value, (uint32)expected) == (uint32)expected);
+      (apr_atomic_cas32((U_32 *)field_addr, (U_32)value, (U_32)expected) == (U_32)expected);
 
     tmn_suspend_enable();
     return (jboolean)(result?JNI_TRUE:JNI_FALSE);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/mon_enter_exit.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/mon_enter_exit.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/mon_enter_exit.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/mon_enter_exit.cpp Thu May 22 06:33:38 2008
@@ -38,14 +38,14 @@
 
 static void vm_monitor_exit_default(ManagedObject *p_obj);
 static void vm_monitor_enter_default(ManagedObject *p_obj);
-static uint32 vm_monitor_try_enter_default(ManagedObject *p_obj);
-static uint32 vm_monitor_try_exit_default(ManagedObject *p_obj);
+static U_32 vm_monitor_try_enter_default(ManagedObject *p_obj);
+static U_32 vm_monitor_try_exit_default(ManagedObject *p_obj);
 
 
 void (*vm_monitor_enter)(ManagedObject *p_obj) = 0;
 void (*vm_monitor_exit)(ManagedObject *p_obj) = 0;
-uint32 (*vm_monitor_try_enter)(ManagedObject *p_obj) = 0;
-uint32 (*vm_monitor_try_exit)(ManagedObject *p_obj) = 0;
+U_32 (*vm_monitor_try_enter)(ManagedObject *p_obj) = 0;
+U_32 (*vm_monitor_try_exit)(ManagedObject *p_obj) = 0;
 
 
 void vm_enumerate_root_set_mon_arrays()
@@ -126,12 +126,12 @@
     hythread_suspend_disable();
 }
 
-static uint32 vm_monitor_try_enter_default(ManagedObject *p_obj) {
-    return (uint32)hythread_thin_monitor_try_enter((hythread_thin_monitor_t *)p_obj->get_obj_info_addr());
+static U_32 vm_monitor_try_enter_default(ManagedObject *p_obj) {
+    return (U_32)hythread_thin_monitor_try_enter((hythread_thin_monitor_t *)p_obj->get_obj_info_addr());
 }
 
-static uint32 vm_monitor_try_exit_default(ManagedObject *p_obj) {
-    return (uint32)hythread_thin_monitor_exit((hythread_thin_monitor_t *)p_obj->get_obj_info_addr());
+static U_32 vm_monitor_try_exit_default(ManagedObject *p_obj) {
+    return (U_32)hythread_thin_monitor_exit((hythread_thin_monitor_t *)p_obj->get_obj_info_addr());
 }
 
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/object_generic.cpp Thu May 22 06:33:38 2008
@@ -113,7 +113,7 @@
     if((vt->class_properties & CL_PROP_ARRAY_MASK) != 0)
     {
         // clone an array
-        int32 length = get_vector_length((Vector_Handle) h->object);
+        I_32 length = get_vector_length((Vector_Handle) h->object);
         size = vt->clss->calculate_array_size(length);
         assert(size > 0);
         result = (ManagedObject*)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/thread_generic.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/thread_generic.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/thread_generic.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/thread_generic.cpp Thu May 22 06:33:38 2008
@@ -270,7 +270,7 @@
 
 void vm_notify_obj_alive(void *p_obj)
 {
-    uint32 obj_info = ((ManagedObject*)p_obj)->get_obj_info();
+    U_32 obj_info = ((ManagedObject*)p_obj)->get_obj_info();
     if (hythread_is_fat_lock(obj_info)) {
         hythread_native_resource_is_live(obj_info);
     }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/verify_stack_enumeration.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/verify_stack_enumeration.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/verify_stack_enumeration.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/thread/verify_stack_enumeration.cpp Thu May 22 06:33:38 2008
@@ -75,8 +75,8 @@
 }
 
 
-typedef void (*add_compressed_root_set_entry_func)(uint32 *ref, Boolean is_pinned);
-static void add_compressed_root_set_entry(uint32 *ref, Boolean is_pinned)
+typedef void (*add_compressed_root_set_entry_func)(U_32 *ref, Boolean is_pinned);
+static void add_compressed_root_set_entry(U_32 *ref, Boolean is_pinned)
 {
     TRACE("compressed root " << *ref << " at " << ref << ", not verified");
 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/crash_dump.cpp Thu May 22 06:33:38 2008
@@ -71,7 +71,7 @@
     bool is_first; // For setting is_ip_past
 };
 
-static uint32 cci_get_inlined_depth(CodeChunkInfo* cci, uint32 offset)
+static U_32 cci_get_inlined_depth(CodeChunkInfo* cci, U_32 offset)
 {
     ASSERT_NO_INTERPRETER
 
@@ -81,16 +81,16 @@
     return cci->get_jit()->get_inline_depth(cci->get_inline_info(), offset);
 }
 
-static Method* get_jit_method(CodeChunkInfo* cci, void* ip, uint32 index, bool is_first)
+static Method* get_jit_method(CodeChunkInfo* cci, void* ip, U_32 index, bool is_first)
 {
     Method* method = cci->get_method();
 
     if (index == 0)
         return method;
 
-    uint32 offset = (uint32)((POINTER_SIZE_INT)ip -
+    U_32 offset = (U_32)((POINTER_SIZE_INT)ip -
         (POINTER_SIZE_INT)cci->get_code_block_addr());
-    uint32 inlined_depth = cci_get_inlined_depth(cci, offset);
+    U_32 inlined_depth = cci_get_inlined_depth(cci, offset);
     bool is_ip_past = !is_first; // || (index != inlined_depth);
 
     if (index > inlined_depth)
@@ -243,9 +243,9 @@
     }
 
     // New cci
-    uint32 offset = (uint32)((POINTER_SIZE_INT)cur_ip -
+    U_32 offset = (U_32)((POINTER_SIZE_INT)cur_ip -
                         (POINTER_SIZE_INT)cci->get_code_block_addr());
-    uint32 inlined_depth = cci_get_inlined_depth(cci, offset);
+    U_32 inlined_depth = cci_get_inlined_depth(cci, offset);
 
     uwinfo->cci = cci;
     uwinfo->inline_index = (int)inlined_depth;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/compile_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/compile_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/compile_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/compile_em64t.cpp Thu May 22 06:33:38 2008
@@ -182,9 +182,9 @@
 // Stack size should be (% 8 == 0) but shouldn't be (% 16 == 0)
 const int ALIGNMENT = 0;
 
-const int32 gr_stack_size = (1 + MAX_GR)*GR_STACK_SIZE
+const I_32 gr_stack_size = (1 + MAX_GR)*GR_STACK_SIZE
         + SHADOW;
-const int32 stack_size = (int32)(m2n_get_size() - 2*sizeof(void*))
+const I_32 stack_size = (I_32)(m2n_get_size() - 2*sizeof(void*))
         + MAX_FR*FR_STACK_SIZE
         + gr_stack_size + ALIGNMENT;
 
@@ -254,7 +254,7 @@
     stub = call(stub, (char *)&compile_me);
 
     // pop m2n from the stack
-    const int32 bytes_to_m2n_bottom = (int32)(stack_size - (m2n_get_size() - 2*sizeof(void*)));
+    const I_32 bytes_to_m2n_bottom = (I_32)(stack_size - (m2n_get_size() - 2*sizeof(void*)));
     stub = m2n_gen_pop_m2n(stub, false, 0, bytes_to_m2n_bottom, 1);
 
     // restore gp inputs from the stack

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/ini_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/ini_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/ini_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/util/em64t/base/ini_em64t.cpp Thu May 22 06:33:38 2008
@@ -82,13 +82,13 @@
     // [rbp + 48] - gr_args
     // [rbp + 56] - fr_args
     // [rbp + 64] - stack_args
-    const int32 METHOD_ENTRY_POINT_OFFSET = 16 + SHADOW;
-    const int32 UNUSED GR_NARGS_OFFSET = 24 + SHADOW;
-    const int32 FR_NARGS_OFFSET = 32 + SHADOW;
-    const int32 STACK_NARGS_OFFSET = 40 + SHADOW;
-    const int32 GR_ARGS_OFFSET = 48 + SHADOW;
-    const int32 FR_ARGS_OFFSET = 56 + SHADOW;
-    const int32 STACK_ARGS_OFFSET = 64 + SHADOW;
+    const I_32 METHOD_ENTRY_POINT_OFFSET = 16 + SHADOW;
+    const I_32 UNUSED GR_NARGS_OFFSET = 24 + SHADOW;
+    const I_32 FR_NARGS_OFFSET = 32 + SHADOW;
+    const I_32 STACK_NARGS_OFFSET = 40 + SHADOW;
+    const I_32 GR_ARGS_OFFSET = 48 + SHADOW;
+    const I_32 FR_ARGS_OFFSET = 56 + SHADOW;
+    const I_32 STACK_ARGS_OFFSET = 64 + SHADOW;
     
     const int STUB_SIZE = 200;
     char * stub = (char *) malloc_fixed_code_for_jit(STUB_SIZE,
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/C_Interface.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/C_Interface.cpp Thu May 22 06:33:38 2008
@@ -61,7 +61,7 @@
 
 
 static unsigned countLeadingChars(const char* str, char c) {
-    uint32 n=0;
+    U_32 n=0;
     while (str[n]==c) {
         n++;
     }
@@ -306,7 +306,7 @@
     JIT *jit = (JIT *)j;
     assert(jit);
 
-    uint32 drlHeat;
+    U_32 drlHeat;
     if (heat == CodeBlockHeatMin)
         drlHeat = CODE_BLOCK_HEAT_COLD;
     else if (heat == CodeBlockHeatMax)
@@ -369,7 +369,7 @@
 
 
 
-uint32
+U_32
 method_get_bytecode_length(Method_Handle m)
 {
     assert(m);
@@ -378,7 +378,7 @@
 
 
 
-uint32 method_get_max_locals(Method_Handle m)
+U_32 method_get_max_locals(Method_Handle m)
 {
     assert(m);
     return m->get_max_locals();
@@ -667,7 +667,7 @@
 
 
 // Returns the address where the interned version of the string is stored: this will be the address
 // of a slot containing a Java_java_lang_String* or a uint32 compressed reference. Also interns the
 // string so that the JIT can load a reference to the interned string without checking if it is null.
 const void *class_get_const_string_intern_addr(Class_Handle cl, unsigned short index)
 {
@@ -1409,8 +1409,8 @@
 
 struct GC_VTable {
     Class_Handle ch;  // for debugging
-    uint32 num_ref_fields;
-    uint32 *ref_fields_offsets;
+    U_32 num_ref_fields;
+    U_32 *ref_fields_offsets;
     unsigned is_array : 1;
     unsigned is_primitive : 1;
 };
@@ -1500,7 +1500,7 @@
     return referent->get_offset();
 }
 
-void* class_alloc_via_classloader(Class_Handle ch, int32 size)
+void* class_alloc_via_classloader(Class_Handle ch, I_32 size)
 {
     assert(ch);
     assert(size >= 0);
@@ -1592,7 +1592,7 @@
 
 
 
-int32 vector_get_length(Vector_Handle vector)
+I_32 vector_get_length(Vector_Handle vector)
 {
     assert(vector);
     // XXX- need some assert that "vector" is really an array type
@@ -1601,7 +1601,7 @@
 
 
 
-Managed_Object_Handle *vector_get_element_address_ref(Vector_Handle vector, int32 idx)
+Managed_Object_Handle *vector_get_element_address_ref(Vector_Handle vector, I_32 idx)
 {
     assert(vector);
     Managed_Object_Handle *elem = (Managed_Object_Handle *)get_vector_element_address_ref(vector, idx);
@@ -667,7 +667,7 @@
 
 // Returns the address where the interned version of the string is stored: this will be the address
-// of a slot containing a Java_java_lang_String* or a uint32 compressed reference. Also interns the
+// of a slot containing a Java_java_lang_String* or a U_32 compressed reference. Also interns the
 // string so that the JIT can load a reference to the interned string without checking if it is null.
 const void *class_get_const_string_intern_addr(Class_Handle cl, unsigned short index)

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/class_support/Class.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/root_set_enum_common.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/gc/root_set_enum_common.cpp Thu May 22 06:33:38 2008
@@ -99,7 +99,7 @@
                     // The field is static and it is a reference.
                     REFS_RUNTIME_SWITCH_IF
 #ifdef REFS_RUNTIME_OR_COMPRESSED
-                        vm_enumerate_compressed_root_reference((uint32 *)f->get_address(), FALSE);
+                        vm_enumerate_compressed_root_reference((U_32 *)f->get_address(), FALSE);
 #endif // REFS_RUNTIME_OR_COMPRESSED
                     REFS_RUNTIME_SWITCH_ELSE
 #ifdef REFS_RUNTIME_OR_UNCOMPRESSED
@@ -193,7 +193,7 @@
 } //vm_enumerate_weak_root_reference
 
 
 // Resembles vm_enumerate_root_reference() but is passed the address of a uint32 slot containing a compressed reference.
 VMEXPORT void vm_enumerate_compressed_root_reference(U_32 *ref, BOOLEAN is_pinned)
 {
     assert(REFS_IS_COMPRESSED_MODE);
@@ -309,10 +309,10 @@
             if (cci->has_inline_info()) {
                 JIT *jit = cci->get_jit();
                 NativeCodePtr ip = si_get_ip(si);
-                uint32 inlined_depth = si_get_inline_depth(si);
+                U_32 inlined_depth = si_get_inline_depth(si);
                 if (inlined_depth) {
-                    uint32 offset = (uint32)((POINTER_SIZE_INT)ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
-                    for (uint32 i = inlined_depth; i > 0; i--) {
+                    U_32 offset = (U_32)((POINTER_SIZE_INT)ip - (POINTER_SIZE_INT)cci->get_code_block_addr());
+                    for (U_32 i = inlined_depth; i > 0; i--) {
                         Method* m = jit->get_inlined_method(cci->get_inline_info(), offset, i);
                         assert (m);
                         cl = m->get_class()->get_class_loader();
@@ -193,7 +193,7 @@
 
 
-// Resembles vm_enumerate_root_reference() but is passed the address of a uint32 slot containing a compressed reference.
+// Resembles vm_enumerate_root_reference() but is passed the address of a U_32 slot containing a compressed reference.
 VMEXPORT void vm_enumerate_compressed_root_reference(U_32 *ref, BOOLEAN is_pinned)
 {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/finalizer_thread.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/init/finalizer_thread.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================